import { NsTypography, NsIcon, NsAccordionHeaderProps, AccordionVariant } from '..';
import { styled, ColorUtils } from '@nuskin/foundation-theme';
const { getPaletteColor } = ColorUtils;

const StyledHeader = styled('header')<{ variant: AccordionVariant }>(({ theme, variant }) => {
    const backgroundColor = getPaletteColor(theme, 'primary', 'contrastText') as string;
    let borderBottom = 'none';
    if (variant === AccordionVariant.Compact) {
        borderBottom = '1px solid rgb(0,0,0,0.125)';
    }
    return {
        backgroundColor,
        cursor: 'pointer',
        display: 'grid',
        gridTemplateColumns: '1fr 24px',
        padding: '9px 16px',
        borderBottom,
    } as any;
});

/**
 * NsAccordionHeader is primarily used by NsToggleSection and NsAccordionItem
 * as a header, so it accepts `title` , `isOpen` and `onClick`
 */
const NsAccordionHeader = ({
    title,
    onClick,
    isOpen,
    additionalProps,
    openedIconName,
    closedIconName,
    variant,
    headerTypographyVariant,
}: NsAccordionHeaderProps) => {
    return (
        <StyledHeader
            role="button"
            aria-expanded={isOpen ? 'true' : 'false'}
            className={`section-header ${isOpen ? 'expanded' : ''} ${additionalProps?.className ?? ''}`}
            onClick={onClick}
            variant={variant}
        >
            {typeof title === 'string' ? (
                <NsTypography variant={headerTypographyVariant ?? 'h4'} weight="bold">
                    {title}
                </NsTypography>
            ) : (
                title
            )}
            <span className="header-icon">
                <NsIcon name={isOpen ? openedIconName ?? 'arrowUp' : closedIconName ?? 'arrowDown'} />
            </span>
        </StyledHeader>
    );
};
export default NsAccordionHeader;
