import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
import { AccordionVariant, NsCollapseProps } from './types.d';
const { getAppColor, getPaletteColor } = ColorUtils;
const getIsLight = (theme: FoundationTheme.Theme) => {
    const { palette = { primary: { main: '', contrastText: '' } } } = theme;
    return palette.primary.main === getAppColor(theme, 'primary', 'black');
};
const options = {
    shouldForwardProp: (key: string) => key !== 'variant',
};
export const StyledCollapse = styled(
    'section',
    options
)<{ variant: AccordionVariant }>(({ theme, variant }) => {
    let backgroundColor = getIsLight(theme)
        ? (getAppColor(theme, 'primary', 'gray') as string)
        : (getAppColor(theme, 'primary', 'dark') as string);
    let borderBottom = 'none';
    if (variant === AccordionVariant.Compact) {
        backgroundColor = getIsLight(theme)
            ? (getAppColor(theme, 'primary', 'white') as string)
            : (getAppColor(theme, 'primary', 'dark') as string);
        borderBottom = '1px solid rgb(0,0,0,0.125)';
    }
    return {
        backgroundColor,
        color: getPaletteColor(theme, 'primary', 'main') as string,
        opacity: 0,
        padding: '0 16px',
        height: 0,
        overflow: 'hidden',
        transition: '0.3s',
        '&.expanded': {
            padding: '9px 16px',
            height: 'auto',
            opacity: 1,
            borderBottom,
        },
    };
});

/**
 * NsCollapse component adds css animation while showing children items if prop `isOpen` is true,
 * and while removing children if prop `isOpen` is false
 */
const NsCollapse = ({ isOpen, children, additionalProps, variant }: NsCollapseProps) => {
    return (
        <StyledCollapse
            className={`ns-collapse ${isOpen ? 'expanded' : ''} ${additionalProps?.className ?? ''}`}
            variant={variant}
        >
            {isOpen ? children : null}
        </StyledCollapse>
    );
};
export default NsCollapse;
