import { Button as MUIButton } from '@mui/material';

import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
import { ButtonConfig } from '@nuskin/foundation-theme/src/common/themes/types/button';

import { NsButtonProps } from './types.d';

const { buttonColor, paletteColor } = ColorUtils;

const getButtonConfig = (theme: FoundationTheme.Theme, attribute: keyof ButtonConfig) => {
    const { config } = theme || {};
    return config?.components?.button?.[attribute] || '';
};

const StyledButton = styled(MUIButton)<NsButtonProps>`
    gap: 10px;
    border-radius: ${({ theme }) => getButtonConfig(theme, 'borderRadius')} || 0;
    :focus {
        border: 1px solid ${({ theme }) => getButtonConfig(theme, 'focusColor')} !important;
    }
    :disabled {
        background-color: ${(btnProps) => buttonColor(btnProps?.color, 'disabled')};
        color: ${(btnProps) => buttonColor(btnProps?.color, 'disabledText')};
    }
    ${({ theme: { config }, size }) => {
        return size === 'medium' ? config?.components?.button?.size?.medium?.padding : '';
    }}
    ${({ theme: { config }, size }) => {
        return size === 'large' ? config?.components?.button?.size?.large?.padding : '';
    }}
    ${({ variant, theme, color = 'primary', darkModeEnabled }) => {
        return variant === 'contained'
            ? `
                background-color: ${paletteColor(color)({ theme, darkModeEnabled })};
                color: ${paletteColor(color, 'contrastText')({ theme, darkModeEnabled })} !important;
                :hover {
                    background-color: ${buttonColor(color, 'hovered')({ theme })};
                }
                :active {
                    background-color: ${buttonColor(color, 'pressed')({ theme })};
                }
                :focus {
                    background-color: ${buttonColor(color, 'focused')({ theme })};
                }
            `
            : '';
    }}
  ${({ variant, theme, color = 'primary', darkModeEnabled }) =>
        variant === 'outlined' &&
        `
            border-color: ${paletteColor(color)({ theme, darkModeEnabled })};
            color: ${paletteColor(color)({ theme, darkModeEnabled })};
            :hover {
                border-color: ${buttonColor(color, 'hovered')({ theme })};
                color: ${paletteColor(color)({ theme, darkModeEnabled })};
            }
            :active {
                border-color: ${buttonColor(color, 'pressed')({ theme })};
                color: ${paletteColor(color)({ theme })};
            }
        `}
  ${({ variant, theme, color = 'primary', darkModeEnabled }) =>
        variant === 'text' &&
        `
            text-decoration: underline 1px !important;
            text-underline-offset: 4px;
            padding: 0;
            min-width: auto;
            background-color: transparent !important;
            text-decoration-color: ${paletteColor(color)({ theme, darkModeEnabled })};
            color: ${paletteColor(color)({ theme, darkModeEnabled })};
            :hover {
                color:  ${buttonColor(color, 'hovered')({ theme })};
                text-decoration-color:  ${buttonColor(color, 'hovered')({ theme })};
            }
            :active {
                color: ${paletteColor(color)};
                text-decoration-color:  ${buttonColor(color, 'pressed')({ theme })};
            }
        `}
  ${({ iconOnly }) =>
        iconOnly &&
        `
            padding: 10px;
            min-width: unset;
        `}
`;

export default StyledButton;
