import React, { useMemo } from 'react';
import Slider from 'react-slick';
import { NsScrollingCarousalProps } from '../';
import { styled } from '@nuskin/foundation-theme';

const options = {
    shouldForwardProp: (prop: string) => prop !== 'dotsBottomPixel',
};

const StyledDiv = styled(
    'div',
    options
)<{
    dotsBottomPixel?: number;
}>(({ dotsBottomPixel }) => {
    return {
        '.slick-dots': {
            zIndex: 9,
            bottom: `${dotsBottomPixel ?? -25}px`,
            opacity: '0.5',
        },
    };
});

const NsScrollingCarousal = ({
    slides,
    scrollSeconds,
    stillSeconds,
    renderSlide,
    settings,
    dotsBottomPixel,
    additionalProps,
}: NsScrollingCarousalProps) => {
    const defaultSettings = useMemo(() => {
        return {
            ...settings,
            autoplay: true,
            autoplaySpeed: stillSeconds * 1000 || 2000, // autoplaySpeed = delay between scroll in milliseconds
            accessibility: true,
            adaptiveHeight: true,
            arrows: true,
            draggable: true,
            dots: true,
            infinite: true,
            speed: scrollSeconds * 1000 || 500, // speed = animation speed in milliseconds
            slidesToShow: 1,
            slidesToScroll: 1,
            swipeToSlide: true,
        };
    }, [stillSeconds, scrollSeconds, settings]);
    return (
        <StyledDiv
            dotsBottomPixel={dotsBottomPixel}
            data-testid={additionalProps?.testid ?? 'scrolling-carousal-test-id'}
        >
            <Slider {...defaultSettings}>{slides.map(renderSlide)}</Slider>
        </StyledDiv>
    );
};

export default NsScrollingCarousal;
