import React, { useState } from 'react';
import { DropdownContainer, DropdownButton, DropdownList, DropdownHead } from './NsDropdown.styled';
import { NsIcon } from '../icon';
import { DropdownProps } from './types.d';

const NsDropdown: React.FC<DropdownProps> = ({
    selectedValue,
    selectedLabel,
    onSelect,
    children,
    disabled = false,
    type = 'outlined',
    placeholder = 'Select',
    dropdownBorderColor = 'accentColorB',
    closeOnMouseLeave = false,
    showListDivider = true,
}) => {
    const [isOpen, setIsOpen] = useState(false);
    const [value, setValue] = useState(selectedValue || '');

    const handleToggle = () => {
        if (disabled) return;
        setIsOpen(!isOpen);
    };

    const closeDropdown = () => {
        if (closeOnMouseLeave) {
            setIsOpen(false);
        }
    };

    const handleSelect = (input: string) => {
        onSelect(input);
        setIsOpen(false);
        setValue(input);
    };

    return (
        <DropdownContainer disabled={disabled}>
            <DropdownHead data-testid="dropdown-head" disabled={disabled} type={type} onClick={handleToggle}>
                <DropdownButton>{selectedLabel || placeholder}</DropdownButton>
                <NsIcon testId="chevron-icon" name={isOpen ? 'arrowUp' : 'arrowDown'} color="primary" />
            </DropdownHead>
            {isOpen ? (
                <DropdownList
                    data-testid="dropdown-list"
                    onMouseLeave={closeDropdown}
                    borderColor={dropdownBorderColor}
                >
                    {React.Children.map(children, (child) => {
                        if (React.isValidElement(child)) {
                            return React.cloneElement(child, {
                                // @ts-ignore
                                onSelect: handleSelect,
                                selectedValue: value,
                                showListDivider,
                            });
                        }
                        return null;
                    })}
                </DropdownList>
            ) : null}
        </DropdownContainer>
    );
};

export default NsDropdown;
