import React from 'react';
import { render, screen, act } from '@testing-library/react';
import NsEmailSimple from './NsEmailSimple';
import { userEvent } from '@storybook/testing-library';
import { emailPattern } from '../validations/regex';

describe('NsEmailSimple', () => {
    let mockCheckEmail = jest.fn().mockResolvedValue([true, false]);
    let propsData = {
        disabled: false,
        label: 'Email',
        required: true,
        maxLength: 50,
        invalidEmailMessage: 'Please enter a valid email',
        dupedEmailMessage: 'Email ID already exists',
        requiredErrorMessage: 'Email field is required',
        checkEmail: mockCheckEmail,
    };
    it('renders email field with invalid regex error', async () => {
        render(<NsEmailSimple {...propsData} />);
        const emailField = (await screen.findByTestId('email-field-test')) as HTMLInputElement;
        expect(emailField).toBeInTheDocument;
        const inputElement = emailField.querySelector('input');
        if (!inputElement) {
            return;
        }
        act(() => {
            userEvent.type(inputElement, 'test');
            userEvent.tab();
        });

        expect(inputElement).toHaveValue('test');

        act(() => {
            userEvent.clear(inputElement);
            userEvent.type(inputElement, 'test@gm');
            userEvent.tab();
        });
        expect(inputElement).toHaveValue('test@gm');

        mockCheckEmail = jest.fn().mockResolvedValue([true, true]);
        render(<NsEmailSimple {...propsData} />);
        act(() => {
            userEvent.clear(inputElement);
            userEvent.type(inputElement, 'test!gmail');
            userEvent.tab();
        });
        expect(inputElement).toHaveValue('test!gmail');
        act(() => {
            userEvent.clear(inputElement);
            userEvent.tab();
        });
        expect(inputElement).toHaveValue('');

        mockCheckEmail = jest.fn().mockResolvedValue([true, false]);
        render(<NsEmailSimple {...propsData} />);
        act(() => {
            userEvent.clear(inputElement);
            userEvent.type(inputElement, 'test@gmail.co');
            userEvent.tab();
        });
        expect(inputElement).toHaveValue('test@gmail.co');
    });
    it('renders email field with invalid error', async () => {
        let mockCheckEmail1 = jest.fn().mockResolvedValue([false, false]);
        let propsData1 = {
            disabled: false,
            label: 'Email',
            required: true,
            maxLength: 50,
            invalidEmailMessage: 'Please enter a valid email',
            dupedEmailMessage: 'Email ID already exists',
            requiredErrorMessage: 'Email field is required',
            checkEmail: mockCheckEmail1,
        };
        render(<NsEmailSimple {...propsData1} />);
        const emailField = (await screen.findByTestId('email-field-test')) as HTMLInputElement;
        expect(emailField).toBeInTheDocument;
        const inputElement = emailField.querySelector('input');
        if (!inputElement) {
            return;
        }
        act(() => {
            userEvent.clear(inputElement);
            userEvent.type(inputElement, 'test@gmail.com');
            userEvent.tab();
        });
        expect(inputElement).toHaveValue('test@gmail.com');
        expect(inputElement.value).toMatch(emailPattern);
    });
    it('renders email field without error', async () => {
        let mockCheckEmail1 = jest.fn().mockResolvedValue([true, true]);
        let propsData1 = {
            disabled: false,
            label: 'Email',
            required: true,
            maxLength: 50,
            invalidEmailMessage: 'Please enter a valid email',
            dupedEmailMessage: 'Email ID already exists',
            requiredErrorMessage: 'Email field is required',
            checkEmail: mockCheckEmail1,
        };
        render(<NsEmailSimple {...propsData1} />);
        const emailField = (await screen.findByTestId('email-field-test')) as HTMLInputElement;
        expect(emailField).toBeInTheDocument;
        const inputElement = emailField.querySelector('input');
        if (!inputElement) {
            return;
        }
        act(() => {
            userEvent.clear(inputElement);
            userEvent.type(inputElement, 'test@gmail.com');
            userEvent.tab();
        });
        expect(inputElement).toHaveValue('test@gmail.com');
        expect(inputElement.value).toMatch(emailPattern);
    });
    it('renders email field with API error', async () => {
        let mockCheckEmail1 = jest.fn().mockResolvedValue(undefined);
        let propsData1 = {
            disabled: false,
            label: 'Email',
            required: true,
            maxLength: 50,
            invalidEmailMessage: 'Please enter a valid email',
            dupedEmailMessage: 'Email ID already exists',
            requiredErrorMessage: 'Email field is required',
            checkEmail: mockCheckEmail1,
        };
        render(<NsEmailSimple {...propsData1} />);
        const emailField = (await screen.findByTestId('email-field-test')) as HTMLInputElement;
        expect(emailField).toBeInTheDocument;
        const inputElement = emailField.querySelector('input');
        if (!inputElement) {
            return;
        }
        act(() => {
            userEvent.clear(inputElement);
            userEvent.type(inputElement, 'test@gmail.com');
            userEvent.tab();
        });
        expect(inputElement).toHaveValue('test@gmail.com');
        expect(inputElement.value).toMatch(emailPattern);
    });
});
