/**
 * @author [vijayaprathap Kumar] (vpkumar@nuskin.com)
 * Flag.styled.tsx
 @description Styled Components for Flag
 */

import { Theme } from '@mui/material';
import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';

import { NsFlagSize } from './types.d';

const { paletteColor } = ColorUtils;

type NsFlagThemeParams = {
    $size: NsFlagSize;
    $bgColor?: FoundationTheme.PaletteColors;
    theme?: Theme;
};

// Scale value used to divide size from props for create tag tail as per Flag width and height;
const FLAG_SCALE_VALUE = 2;

const FlagHeightMap = {
    small: 20,
    medium: 24,
    large: 28,
};

const getFlagHeight = ({ $size }: { $size: NsFlagSize }) => {
    return FlagHeightMap[$size] || FlagHeightMap['small' as NsFlagSize];
};

const makeFlagSize = ({ $size }: { $size: NsFlagSize }) => {
    const sizeValue = getFlagHeight({ $size });
    return sizeValue / FLAG_SCALE_VALUE;
};

const makeFlagBorder = ({ $size, $bgColor = 'accentColorA', theme }: NsFlagThemeParams) => {
    if (theme) {
        return `${makeFlagSize({ $size })}px solid ${paletteColor($bgColor)({ theme })}`;
    }
    return '';
};

export const StyledFlag = styled('span')<NsFlagThemeParams>`
    min-width: 29px;
    height: ${getFlagHeight}px;
    color: ${({ $bgColor = 'accentColorA', theme }) => paletteColor($bgColor, 'contrastText')({ theme })};
    background: ${({ $bgColor = 'accentColorA', theme }) => paletteColor($bgColor)({ theme })};
    position: relative;
    padding: 0 15px;
    display: inline-grid;
    align-content: space-around;
    :before {
        position: absolute;
        top: 0;
        right: -${makeFlagSize}px;
        content: '';
        width: 0;
        height: 0;
        display: block;
        border-right: ${makeFlagSize}px solid transparent;
        border-top: ${makeFlagBorder};
    }
    :after {
        position: absolute;
        top: 0;
        right: -${makeFlagSize}px;
        content: '';
        width: 0;
        height: ${makeFlagSize}px;
        display: block;
        border-right: ${makeFlagSize}px solid transparent;
        border-bottom: ${makeFlagBorder};
    }
`;
