import { CSSProperties } from 'react';

import { FormLabel } from '@mui/material';

import { styled, ColorUtils } from '@nuskin/foundation-theme';

import { NsLabelProps } from './types.d';

const { paletteColor, isDarkMode, color } = ColorUtils;

const StyledLabel = styled(FormLabel)<{ fontSize?: number; style?: CSSProperties }>(({ theme, fontSize, style }) => {
    const isLight = !isDarkMode({ theme });
    return {
        fontSize: fontSize ? `${fontSize}px` : '14px',
        textAlign: style?.textAlign ?? 'left',
        color: paletteColor('primary', 'main')({ theme }),
        '.optional-label': {
            color: isLight ? color('neutral', '60')({ theme }) : color('neutral', '50')({ theme }),
        },
        '.MuiInputLabel-asterisk': {
            color: isLight ? color('error', '40')({ theme }) : color('error', '20')({ theme }),
        },
        ...(style || {}),
    } as any; // TODO: may be this "any" has to be fixed from foundation-theme
});

const NsLabel = (props: NsLabelProps) => {
    const { required, showOptional, children, size } = props;
    return (
        <StyledLabel {...props} fontSize={size} required={required}>
            {children}
            {!required && showOptional ? <span className="optional-label">{' (Optional)'}</span> : null}
        </StyledLabel>
    );
};
export default NsLabel;
