import { Radio, FormControlLabel, FormLabel, RadioGroup } from '@mui/material';
import { ColorUtils, FoundationTheme, styled } from '@nuskin/foundation-theme';

const { paletteColor, isDarkMode, color } = ColorUtils;

export const StyledHelperText = styled('div')`
    margin-top :10px;
    padding-left: 0.5em;
    text-align: left;
    justify-self: flex-start;
)`;

export const StyledSpan = styled('span')`
    font-size: '16px';
    font-weight: 300;
    color: ${paletteColor('primary')};
`;

export const StyledLabel = styled(FormLabel)`
    color: ${paletteColor('primary')},
    marginBottom: '15px',
    backgroundColor: 'transparent',
`;

export const StyledRadio = styled(Radio)`
    color: ${(props) => !isDarkMode(props) ? color('primary', 'black')(props) : color('primary', 'white')(props)}
`;

export const StyledFormControlLabel = styled(FormControlLabel)<{ darkModeEnabled?: boolean }>((props) => {
    return {
        color: paletteColor('primary')(props),
        marginBottom: '10px',
        '.MuiFormControlLabel-label.Mui-disabled': {
            color: `${!isDarkMode(props) ? color('neutral', 60)(props) : color('neutral', 20)(props)}`
        },
    };
});

export const StyledRadioGroup = styled(RadioGroup)<
    { color: FoundationTheme.PaletteColors; darkModeEnabled?: boolean }
>(
    ({ theme, color, darkModeEnabled }) => {
        return {
            marginTop: '10px',
            '.MuiRadio-root.custom-radio.Mui-checked': {
                color: paletteColor(color)({ theme, darkModeEnabled })
            },
        };
    }
);
