import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
const { color, paletteColor, isDarkMode } = ColorUtils;

export const SelectContainer = styled.div<{ disabled: boolean }>`
    position: relative;
    display: inline-block;
    opacity: ${({ disabled }) => (disabled ? '0.5' : '1')};
`;

export const SelectHead = styled.div<{ type: string; disabled: boolean }>`
    cursor: ${({ disabled }) => (disabled ? 'inherit' : 'pointer')};
    padding: 5px 10px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    border: ${({ type, theme }) =>
        type === 'outlined' ? `1px solid ${color('primary', 'black')({ theme })}` : 'none'};
    color: ${paletteColor('primary')};
    width: 207px;
    position: relative;
    z-index: 2;
`;

export const SelectButton = styled.div`
    padding-right: 10px;
`;

export const SelectList = styled.div<{ borderColor: FoundationTheme.PaletteColors }>`
    position: absolute;
    z-index: 100;
    border: 1px solid ${({ borderColor, theme }) => paletteColor(borderColor)({ theme })};
    padding: 0;
    margin: 0;
    width: -webkit-fill-available;
    color: ${paletteColor('primary')};
    background-color: ${paletteColor('primary', 'contrastText')};
`;

const getDividerColor = (props: { theme: FoundationTheme.Theme}) => {
    const dividerColor = !isDarkMode(props) ? color('neutral', '30')(props) : color('neutral', '20')(props);
    return dividerColor;
};

const getListBgColor = (props: { theme: FoundationTheme.Theme }) => {
    const bgColor = !isDarkMode(props) ? color('accentColorB', '10')(props) : color('accentColorB', '50')(props);
    return bgColor;
};

export const ListItemContainer = styled.div<{ showListDivider: boolean; isSelected: boolean }>`
     ${({ showListDivider, isSelected, theme }) => `
        cursor: pointer;
        padding: 5px 0;
        border-bottom: 1px solid ${showListDivider ? getDividerColor({ theme }) : 'none'};
        background-color: ${isSelected ? paletteColor('primary')({ theme }) : 'white'};
        color: ${isSelected ? 'white' : 'black'};

        &:hover {
            background-color: ${getListBgColor({ theme })};
        }

        &:last-child {
            border-bottom: none;
        }
    `}
`;

export const ListItem = styled.div<{ isSelected: boolean}>`
    padding: 5px 10px;
    border-left: ${({ isSelected, theme }) =>
        isSelected ? `2px solid ${paletteColor('primary')({ theme })}` : 'none'};
    background-color: ${({ isSelected, theme }) =>
        isSelected ? paletteColor('primary', 'main')({ theme }) : 'white'};
    color: ${({ isSelected }) => (isSelected ? 'white' : 'black')};
    &:hover {
        background-color: ${({ isSelected, theme }) =>
        isSelected ? paletteColor('primary')({ theme }) : getListBgColor({ theme })};
            font-weight: bold; 
    }
`;

export const SelectLabel = styled.label`
    display: block;
    margin-bottom: 5px;
    color: ${paletteColor('primary')} !important;
`;
